# Virtual Machine Work Log

A virtual machine work log represents a working log that authors do actions to the virtual compute instance hosted within a cluster. Each VM work log must be assigned to exactly one VM.